package com.ontestautomation.testnet.exercises;

import static com.jayway.restassured.RestAssured.given;
import static org.hamcrest.Matchers.*;

import org.testng.annotations.Test;

public class RestAssuredExercises1 {
	
	/*******************************************************
	 * Stuur een GET-request naar
	 * http://ergast.com/api/f1/2015/drivers.json
	 * en valideer dat die wordt beantwoord met een HTTP 200 
	 ******************************************************/
	
	@Test
	public void checkResponseCodeForCorrectRequest() {
		
		given().
		when().
			get("http://ergast.com/api/f1/2015/drivers.json").
		then().
			assertThat().
			statusCode(200);
	}
	
	/*******************************************************
	 * Stuur een GET-request naar
	 * http://ergast.com/api/f1/incorrect.json
	 * en valideer dat die wordt beantwoord met een HTTP 400 
	 ******************************************************/
	
	@Test
	public void checkResponseCodeForIncorrectRequest() {
		
		given().
		when().
			get("http://ergast.com/api/f1/incorrect.json").
		then().
			assertThat().
			statusCode(400);
	}
	
	/*******************************************************
	 * Stuur een GET-request naar
	 * http://ergast.com/api/f1/2015/drivers.json
	 * en valideer dat het antwoord in correct JSON-formaat is 
	 ******************************************************/
	
	@Test
	public void checkResponseContentTypeJson() {
		
		given().
		when().
			get("http://ergast.com/api/f1/2015/drivers.json").
		then().
			assertThat().
			contentType("application/json");
	}

	/***********************************************
	 * Haal de circuitinformatie voor de eerste race
	 * van 2014 op en valideer dat het circuitId gelijk
	 * is aan albert_park
	 * Gebruik http://ergast.com/api/f1/2014/1/circuits.json
	 **********************************************/
	
	@Test
	public void checkTheFirstRaceOf2014WasAtAlbertPark() {
		
		given().
		when().
			get("http://ergast.com/api/f1/2014/1/circuits.json").
		then().
			assertThat().
			body("MRData.CircuitTable.Circuits.circuitId[0]",equalTo("albert_park"));
	}
	
	/***********************************************
	 * Haal de lijst van circuits voor 2014 op
	 * en valideer dat Silverstone daar bij is
	 **********************************************/
	
	@Test
	public void checkThereWasARaceAtSilverstoneIn2014() {

		given().
		when().
			get("http://ergast.com/api/f1/2014/circuits.json").
		then().
			assertThat().
			body("MRData.CircuitTable.Circuits.circuitId",hasItem("silverstone"));
	}

	/***********************************************
	 * Haal de lijst van circuits voor 2014 op
	 * en valideer dat Nurburgring daar niet bij is
	 **********************************************/
	
	@Test
	public void checkThereWasNoRaceAtNurburgringIn2014() {

		given().
		when().
			get("http://ergast.com/api/f1/2014/circuits.json").
		then().
			assertThat().
		body("MRData.CircuitTable.Circuits.circuitId",not(hasItem("nurburgring")));
	}
}
