package com.ontestautomation.testnet.exercises;

import static com.jayway.restassured.RestAssured.given;
import static org.hamcrest.Matchers.*;

import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

public class RestAssuredExercises2 {
	
	/*******************************************************
	 * Creeer een DataProvider waarin je specificeert in welk
	 * land een bepaald circuit ligt (specificeer bijv. dat
	 * Monza in Italie ligt) 
	 ******************************************************/
	
	@DataProvider(name = "circuits")
	public String[][] createCircuitData() {
		return new String[][] {
				{ "monza", "Italy" },
				{ "spa", "Belgium" },
				{ "sepang", "Malaysia" }
		};
	}
	
	/*******************************************************
	 * Creeer een DataProvider waarmee je voor elke race
	 * (de eerste vier is voldoende) in 2015 kunt
	 * specificeren hoeveel pitstops Max Verstappen heeft
	 * gemaakt (race 1 = 1 pitstop, 2 = 3, 3 = 2, 4 = 2)
	 ******************************************************/
	
	@DataProvider(name = "pitstops")
	public Object[][] createPitstopData() {
		return new Object[][] {
				{ "1", 1 },
				{ "2", 3 },
				{ "3", 2 },
				{ "4", 2 }
		};
	}
	
	/*******************************************************
	 * Vraag gegevens voor een specifiek circuit op (voor
	 * Monza is dit http://ergast.com/api/f1/circuits/monza.json
	 * en valideer het land waarin dit circuit ligt 
	 ******************************************************/	
	
	@Test(dataProvider = "circuits")
	public void checkCountryForCircuit(String circuitName, String circuitCountry) {
		
		given().
			pathParameter("circuitName", circuitName).
		when().
			get("http://ergast.com/api/f1/circuits/{circuitName}.json").
		then().
			assertThat().
			body("MRData.CircuitTable.Circuits.Location[0].country",equalTo(circuitCountry));
	}
	
	/*******************************************************
	 * Vraag de pitstop-gegevens voor de eerste vier races
	 * van 2015 op voor Max Verstappen (voor race 1 is dit
	 * http://ergast.com/api/f1/2015/1/drivers/max_verstappen/pitstops.json)
	 * en valideer het aantal pitstops
	 ******************************************************/
	
	@Test(dataProvider = "pitstops")
	public void checkNumberOfPitstopsForMaxVerstappenIn2015(String raceNumber, int numberOfPitstops) {
		
		given().
			pathParameter("raceNumber", raceNumber).
		when().
			get("http://ergast.com/api/f1/2015/{raceNumber}/drivers/max_verstappen/pitstops.json").
		then().
			assertThat().
			body("MRData.RaceTable.Races[0].PitStops",hasSize(numberOfPitstops));
	}
}
